@@ -1,5 +1,5 @@
 <?php
-// $Id: xoopslists.php,v 1.4 2005/08/03 12:39:11 onokazu Exp $
+// $Id: xoopslists.php,v 1.4.6.1 2006/02/06 08:37:39 onokazu Exp $
 //  ------------------------------------------------------------------------ //
 //                XOOPS - PHP Content Management System                      //
 //                    Copyright (c) 2000 XOOPS.org                           //
@@ -46,7 +46,8 @@ if ( !defined("XOOPS_LISTS_INCLUDED") ) {
          */
         function &getThemesList()
         {
-            return XoopsLists::getDirListAsArray(XOOPS_THEME_PATH.'/');
+            $ret =& XoopsLists::getDirListAsArray(XOOPS_THEME_PATH.'/');
+            return $ret;
         }
 
         /*
@@ -54,7 +55,8 @@ if ( !defined("XOOPS_LISTS_INCLUDED") ) {
          */
         function &getModulesList()
         {
-            return XoopsLists::getDirListAsArray(XOOPS_ROOT_PATH."/modules/");
+            $ret =& XoopsLists::getDirListAsArray(XOOPS_ROOT_PATH."/modules/");
+            return $ret;
         }
 
         /*
@@ -172,10 +174,10 @@ if ( !defined("XOOPS_LISTS_INCLUDED") ) {
                 foreach ( $dirlist as $dir ) {
                     $avatars[$dir] =& XoopsLists::getImgListAsArray(XOOPS_ROOT_PATH."/images/avatar/".$dir."/", $dir."/");
                 }
-            } else {
-                return false;
+                return $avatars;
             }
-            return $avatars;
+            $ret = false;
+            return $ret;
         }
 
         /*
