@@ -1,5 +1,5 @@
 <?php
-// $Id: system_blocks.php,v 1.6 2005/09/04 20:46:12 onokazu Exp $
+// $Id: system_blocks.php,v 1.6.4.2 2006/02/05 05:19:53 onokazu Exp $
 //  ------------------------------------------------------------------------ //
 //                XOOPS - PHP Content Management System                      //
 //                    Copyright (c) 2000 XOOPS.org                           //
@@ -116,7 +116,7 @@ function b_system_main_show()
     $modules =& $module_handler->getObjects($criteria, true);
     $moduleperm_handler =& xoops_gethandler('groupperm');
     $groups = is_object($xoopsUser) ? $xoopsUser->getGroups() : XOOPS_GROUP_ANONYMOUS;
-    $read_allowed =& $moduleperm_handler->getItemIds('module_read', $groups);
+    $read_allowed = $moduleperm_handler->getItemIds('module_read', $groups);
     foreach (array_keys($modules) as $i) {
         if (in_array($i, $read_allowed)) {
             $block['modules'][$i]['name'] = $modules[$i]->getVar('name');
@@ -344,7 +344,7 @@ function b_system_comments_show($options)
         }
         $com['id'] = $i;
         $com['title'] = '<a href="'.XOOPS_URL.'/modules/'.$modules[$mid]->getVar('dirname').'/'.$comment_config[$mid]['pageName'].'?'.$comment_config[$mid]['itemName'].'='.$comments[$i]->getVar('com_itemid').'&amp;com_id='.$i.'&amp;com_rootid='.$comments[$i]->getVar('com_rootid').'&amp;'.htmlspecialchars($comments[$i]->getVar('com_exparams')).'#comment'.$i.'">'.$comments[$i]->getVar('com_title').'</a>';
-        $com['icon'] = $comments[$i]->getVar('com_icon');
+        $com['icon'] = htmlspecialchars($comments[$i]->getVar('com_icon'), ENT_QUOTES);
         $com['icon'] = ($com['icon'] != '') ? $com['icon'] : 'icon1.gif';
         $com['time'] = formatTimestamp($comments[$i]->getVar('com_created'),'m');
         if ($comments[$i]->getVar('com_uid') > 0) {
